#Figures

#Base de dados
rm(list=ls())
df=read.csv2("dataset.horses.csv",h=T,d=",",na.strings=".",row.names=1)
df$Breed=factor(df$Breed)
df$Stress.Score=factor(df$Stress.Score,levels=c('0','1','2','3','4','5'),labels=c('Score 0','Score 1','Score 2','Score 3','Score 4','Score 5'))
str(df)

#Boxplot modelo 1
#Salvando em tiff

tiff("ITR_Box1.tiff",width=10,height=6,units='in',res=600, 
     compression=c("none","rle","lzw","jpeg","zip","lzw+p","zip+p"),
     family="sans")
ggplot(df,aes(y=IRT,x='',width=.7))+
  geom_violin(position=position_dodge(.94),width=.55,fill="gray90",color="gray40")+
  geom_boxplot(position=position_dodge(.94),
               width=.3,show.legend=F,size=.8,color="gray40")+
  stat_summary(fun=mean,geom="point",size=10,shape=18,
               color="#E16462FF",alpha=.99,position=position_dodge(0.94),show.legend=F)+
  ylab("Infrared Thermography (ºC)")+
  xlab("")+
  scale_y_continuous(n.breaks=10)+
  geom_jitter(size=5,width=.14,shape=21,color='black',fill='#2A788EFF',alpha=.6)+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"))
dev.off()

#Boxplot modelo 2
#Salvando figura vetorizada

pdf("ITR_Box2.pdf",width=10,height=6,
     family="sans")

ggplot(df,aes(y=IRT,x=Breed,width=.7))+
  geom_violin(position=position_dodge(.94),width=.55,fill="gray90",color="gray40")+
  geom_boxplot(position=position_dodge(.94),width=.24,show.legend=F,size=.8,color="gray40")+
  stat_summary(fun=mean,geom="point",size=10,shape=18,color="#E16462FF",alpha=.9,position=position_dodge(0.94),show.legend=F)+
  ylab("Infrared Thermography (ºC)")+
  xlab("Breed")+
  scale_y_continuous(n.breaks=10)+
  geom_jitter(size=3.6,width=.11,shape=21,color='black',fill='#2A788EFF',alpha=.6)+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"))+
     annotate("text",y=37.6,x=1,label="b",angle=0,color='black',size=5)+
     annotate("text",y=38.2,x=2,label="a",angle=0,color='black',size=5)

dev.off()

# Histograma

ggplot(df,aes(x=IRT))+
  geom_histogram(color="gray10",fill='#FDE725FF',bins=10,alpha=.4,size=.8)+
  geom_density(color='#440154FF',size=2)+
  xlab("Infrared Thermography (ºC)")+
  ylab("Density")+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"))


hist(df$IRT)
boxplot(IRT~Breed,df)

# Densidade modelo 1

ggplot(df,aes(x=IRT))+
  geom_density(color="gray10",fill='#2A788EFF',bins=10,alpha=.4,size=1.2)+
  xlab("Infrared Thermography (ºC)")+
  ylab("Density")+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"))

#Densidade modelo 2

ggplot(df,aes(x=IRT))+
  geom_density(size=1.2)+
  geom_vline(aes(xintercept=mean(IRT)),
             color="#2A788EFF",linetype="dashed",size=1.2)+
  xlab("Infrared Thermography (ºC)")+
  ylab("Density")+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"))+
  annotate("text",y=.06,x=37.27,label="mean",angle=90,color='#2A788EFF',size=5)

#Densidade modelo 3

ggplot(df,aes(x=IRT,fill=Breed))+
  geom_density(color='gray20',size=1.2)+
  geom_vline(aes(xintercept=mean(filter(df,Breed=='Quarter Mile')$IRT)),
             color="black",linetype="dashed",size=1.2)+
  geom_vline(aes(xintercept=mean(filter(df,!Breed=='Quarter Mile')$IRT)),
             color="black",linetype="dashed",size=1.2)+
  xlab("Infrared Thermography (ºC)")+
  ylab("Density")+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"),
                        legend.position='bottom')+
  scale_fill_viridis_d(alpha=.5,option='D',end=.99,begin=.01)+
  annotate("text",y=.56,x=37.1,label="mean Quarter Mile",angle=90,color='black',size=5)+
  annotate("text",y=.59,x=37.6,label="mean Thoroughbred",angle=90,color='black',size=5)

#Dispersao

df%>%
  ggplot(aes(x=Cortisol,y=IRT))+
  geom_smooth(method="lm",formula=y~x,se=T,show.legend=T,size=2,color='#22A884FF',alpha=.3)+
  geom_point(size=5,alpha=.4,show.legend=T,color='#440154FF')+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  labs(y="Infrared Thermography (ºC)",x="Cortisol")+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"))+
  scale_fill_viridis_d()+scale_color_viridis_d()

df%>%
  ggplot(aes(x=Cortisol,y=IRT,color=Breed))+
  geom_smooth(method="lm",formula=y~x,se=T,show.legend=T,size=2,alpha=.18)+
  geom_point(size=5,alpha=.4,show.legend=F)+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  labs(y="Infrared Thermography (ºC)",x="Cortisol")+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"),
                        legend.position='bottom')+
  scale_fill_viridis_d()+scale_color_viridis_d(end=.8)


pp=df%>%
  ggplot(aes(x=Cortisol,y=IRT,color=Breed))+
  geom_smooth(method="lm",formula=y~x,se=T,show.legend=T,size=2,alpha=.18)+
  geom_point(size=5,alpha=.4,show.legend=F)+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  labs(y="Infrared Thermography (ºC)",x="Cortisol")+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"),
                        legend.position='bottom')+
  scale_fill_viridis_d()+scale_color_viridis_d(end=.8);pp

ggplotlyr(pp)

ppp=df%>%
  ggplot(aes(x=Cortisol,y=IRT))+
  geom_smooth(method="lm",formula=y~x,se=T,show.legend=T,size=2,color='#22A884FF',alpha=.3)+
  geom_point(size=5,alpha=.4,show.legend=T,color='#440154FF')+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  labs(y="Infrared Thermography (ºC)",x="Cortisol")+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank(),
                        plot.margin = unit(c(1,1,1,1),"cm"))+
  scale_fill_viridis_d()+scale_color_viridis_d();ppp

ggplotlyr(ppp)

grid.arrange(pp,ppp,nrow=2,ncol=1)
