#Modelo de Regresão Linear Simples

#Base de dados
rm(list=ls())
df=read.csv2("dataset.horses.csv",h=T,d=",",na.strings=".",row.names = 1)
df$Breed=factor(df$Breed)
df$Stress.Score=factor(df$Stress.Score, levels=c('0','1','2','3','4','5'),labels = c('Score 0','Score 1','Score 2','Score 3','Score 4','Score 5'))
str(df)

ggplot(df,aes(x=IRT))+
  geom_histogram(color="gray10",fill='#FDE725FF',bins=10,alpha=.4,size=1)+
  geom_density(color='#440154FF',size=2)+
  xlab(expression(paste("Infrared Thermography (ºC)")))+
  ylab(expression(paste("Density")))+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank())


shapiro.test(df$IRT);cvm.test(df$IRT)

hist(rnorm(20, mean(df$IRT),sd(df$IRT)))

df%>%
  ggplot(aes(x=Cortisol,y=IRT))+
  geom_smooth(method="lm",formula=y~x,se=T,show.legend=T,size=2,color='#22A884FF',alpha=.3)+
  geom_point(size=5,alpha=.4,show.legend=T,color='#440154FF')+
  scale_y_continuous(n.breaks=10)+
  scale_x_continuous(n.breaks=10)+
  labs(y="Infrared Thermography (ºC)",x="Cortisol")+
  theme_classic()+theme(axis.text=element_text(size=10),
                        axis.title=element_text(size=18,face="bold"),
                        legend.text=element_text(size=12,face='bold'),
                        legend.title = element_text(face="bold",size=12),
                        panel.grid.minor = element_blank(),
                        panel.grid.major = element_blank())+
  scale_fill_viridis_d()+scale_color_viridis_d()

cor.test(df$IRT,df$Cortisol)

sink()
con=file("ModeloLinearSimples.log");sink(con,append=T);sink(con,append=T,type="output")
source("script.R",echo=TRUE,max.deparse.length=10000000000)
options(max.print=1000000000)

SLM=lm(IRT~Cortisol
       ,df)

FitModel=SLM
shapiro.test(resid(FitModel))
cvm.test(resid(FitModel))
hist(resid(FitModel))
qqnorm(resid(FitModel))
ols_test_breusch_pagan(FitModel)
summary(FitModel)
summ(FitModel)

logLik(FitModel)
AIC(FitModel)
BIC(FitModel)

NLM=lm(IRT~1,df)

lrtest(NLM,FitModel)

sink()